@@ -86,7 +86,7 @@ bool KoWmfReadPrivate::load(const QByteArray& array)
     // read and check the header
     WmfEnhMetaHeader eheader;
     WmfMetaHeader header;
-    WmfPlaceableHeader pheader;
+    WmfPlaceableHeader pheader; // Contains a bounding box
     unsigned short checksum;
     int filePos;
 
@@ -104,10 +104,14 @@ bool KoWmfReadPrivate::load(const QByteArray& array)
     mEnhanced = false;
 
     // Initialize the bounding box.
-    mBBoxTop = 32767;           // Is there a constant for this?
+    //mBBoxTop = 0;           // The default origin is (0, 0).
+    //mBBoxLeft = 0;
+    mBBoxTop = 32767;
     mBBoxLeft = 32767;
     mBBoxRight = -32768;
     mBBoxBottom = -32768;
+    mMaxWidth = 0;
+    mMaxHeight = 0;
 
 #if DEBUG_RECORDS
     kDebug(31000) << "--------------------------- Starting parsing WMF ---------------------------";
@@ -116,6 +120,10 @@ bool KoWmfReadPrivate::load(const QByteArray& array)
     if (pheader.key == (quint32)APMHEADER_KEY) {
         //----- Read placeable metafile header
         mPlaceable = true;
+#if DEBUG_RECORDS
+        kDebug(31000) << "Placeable header!  Yessss!";
+#endif
+
         st >> pheader.handle;
         st >> pheader.left;
         st >> pheader.top;
@@ -144,6 +152,12 @@ bool KoWmfReadPrivate::load(const QByteArray& array)
         mBBoxTop    = pheader.top;
         mBBoxRight  = pheader.right;
         mBBoxBottom = pheader.bottom;
+#if DEBUG_RECORDS
+        kDebug(31000) << "bounding box in header: " << mBBoxLeft << mBBoxTop << mBBoxRight << mBBoxBottom
+                      << "width, height: " << mBBoxRight - mBBoxLeft << mBBoxBottom - mBBoxTop;
+#endif
+        mMaxWidth   = abs(pheader.right - pheader.left);
+        mMaxHeight  = abs(pheader.bottom - pheader.top);
 
         mDpi = pheader.inch;
     } else {
@@ -202,78 +216,11 @@ bool KoWmfReadPrivate::load(const QByteArray& array)
 
     // check bounding rectangle for standard meta file
     if (mStandard && mValid) {
-        quint16 numFunction = 1;
-        quint32 size;
-
-        // Search for records setWindowOrg and setWindowExt to
-        // determine what the total bounding box of this WMF is.
-        // This initialization assumes that setWindowOrg comes before setWindowExt.
-        qint16 curOrgX = 0;
-        qint16 curOrgY = 0;
-        while (numFunction) {
-
-            filePos = mBuffer->pos();
-            st >> size >> numFunction;
-
-            if (size == 0) {
-                kDebug(31000) << "KoWmfReadPrivate: incorrect file!";
-                mValid = 0;
-                break;
-            }
-
-            numFunction &= 0xFF;
-            if (numFunction == 11) {
-                // setWindowOrg
-
-                st >> curOrgY >> curOrgX;
-                //kDebug(31000) << "setWindowOrg" << curOrgX << curOrgY;
-                if (curOrgY < mBBoxTop)    mBBoxTop = curOrgY;
-                if (curOrgX < mBBoxLeft)   mBBoxLeft = curOrgX;
-                if (curOrgX > mBBoxRight)  mBBoxRight = curOrgX;
-                if (curOrgY > mBBoxBottom) mBBoxBottom = curOrgY;
-            }
-            else if (numFunction == 12) {
-                // setWindowExt
-                qint16 width;
-                qint16 height;
-
-                st >> height >> width;
-                //kDebug(31000) << "setWindowExt" << width << height
-                //              << "(curOrg = " << curOrgX << curOrgY << ")";
-
-                // Negative values are allowed
-                if (width < 0) {
-                    if (curOrgX + width < mBBoxLeft) {
-                        mBBoxLeft = curOrgX + width;
-                    }
-                }
-                else {
-                    if (curOrgX + width > mBBoxRight) {
-                        mBBoxRight = curOrgX + width;
-                    }
-                }
-
-                if (height < 0) {
-                    if (curOrgY + height < mBBoxTop) {
-                        mBBoxTop = curOrgY + height;
-                    }
-                }
-                else {
-                    if (curOrgY + height > mBBoxBottom) {
-                        mBBoxBottom = curOrgY + height;
-                    }
-                }
-            }
-
-            //kDebug(31000) << "              mBBoxTop = " << mBBoxTop;
-            //kDebug(31000) << "mBBoxLeft = " << mBBoxLeft << "  mBBoxRight = " << mBBoxRight;
-            //kDebug(31000) << "           MBBoxBotton = " << mBBoxBottom;
-
-            mBuffer->seek(filePos + (size << 1));
-        }
+        // Note that this call can change mValid.
+        createBoundingBox(st);
     }
 
-    return (mValid);
+    return mValid;
 }
 
 
@@ -316,11 +263,16 @@ bool KoWmfReadPrivate::play(KoWmfRead* readWmf)
     // Set the output strategy.
     mReadWmf = readWmf;
 
-    // Set the full bounding box as the output window just to have something to go with.
-    mWindowTop    = mBBoxTop;
-    mWindowLeft   = mBBoxLeft;
-    mWindowWidth  = mBBoxRight - mBBoxLeft;
-    mWindowHeight = mBBoxBottom - mBBoxTop;
+    // Set some initial values.
+    mWindowTop    = 0;
+    mWindowLeft   = 0;
+    mWindowWidth  = 1;
+    mWindowHeight = 1;
+    mViewportTop    = 0;
+    mViewportLeft   = 0;
+    mViewportWidth  = 1;
+    mViewportHeight = 1;
+
     if (mReadWmf->begin()) {
         // play wmf functions
         mBuffer->seek(mOffsetFirstRecord);
@@ -393,9 +345,255 @@ bool KoWmfReadPrivate::play(KoWmfRead* readWmf)
 }
 
 
+//-----------------------------------------------------------------------------
+
+
+void KoWmfReadPrivate::createBoundingBox(QDataStream &st)
+{
+    // Check bounding rectangle for standard meta file.
+    // This calculation is done in device coordinates.
+    if (!mStandard || !mValid) 
+        return;
+
+    bool windowExtIsSet = false;
+    bool viewportExtIsSet = false;
+
+    quint16 numFunction = 1;
+    quint32 size;
+
+    int filePos;
+
+    // Search for records setWindowOrg and setWindowExt to
+    // determine what the total bounding box of this WMF is.
+    // This initialization assumes that setWindowOrg comes before setWindowExt.
+    qint16 windowOrgX = 0;
+    qint16 windowOrgY = 0;
+    qint16 windowWidth = 0;
+    qint16 windowHeight = 0;
+    qint16 viewportOrgX = 0;
+    qint16 viewportOrgY = 0;
+    qint16 viewportWidth = 0;
+    qint16 viewportHeight = 0;
+    bool   bboxRecalculated = false;
+    while (numFunction) {
+
+        filePos = mBuffer->pos();
+        st >> size >> numFunction;
+
+        if (size == 0) {
+            kDebug(31000) << "KoWmfReadPrivate: incorrect file!";
+            mValid = 0;
+            return;
+        }
+
+        bool  isOrgOrExt = true;
+        bool  doRecalculateBBox = false;
+        qint16  orgX;
+        qint16  orgY;
+        qint16  extX;
+        qint16  extY;
+        switch (numFunction &= 0xFF) {
+        case 11: // setWindowOrg
+            {
+                st >> windowOrgY >> windowOrgX;
+                bboxRecalculated = false;
+#if DEBUG_RECORDS
+                kDebug(31000) << "setWindowOrg" << windowOrgX << windowOrgY;
+#endif
+                if (!windowExtIsSet)
+                    break;
+
+                // If there is actually a viewport, then the bounding
+                // box doesn't change just because we get a new
+                // window.  Remember we are working in device
+                // (viewport) coordinates when deciding the bounding box.
+                if (viewportExtIsSet)
+                    break;
+
+                // If there is no viewport, then use the window as a bounding box.
+                //
+                // Note that the windowOrg only will have an effect on
+                // the bounding box the first time it appears,
+                // immediately after the initialization of it.
+                //
+                // FIXME: Handle the case where the window is defined
+                //        first and then the viewport, without any
+                //        drawing in between.  If that happens, I
+                //        don't think that the window definition
+                //        should influence the bounding box.
+                orgX = windowOrgX;
+                orgY = windowOrgY;
+                extX = windowWidth;
+                extY = windowHeight;
+                //doRecalculateBBox = true;
+            }
+            break;
+
+        case 12: // setWindowExt
+            {
+                st >> windowHeight >> windowWidth;
+                windowExtIsSet = true;
+                bboxRecalculated = false;
+
+#if DEBUG_RECORDS
+                kDebug(31000) << "setWindowExt" << windowWidth << windowHeight
+                              << "(viewportOrg = " << viewportOrgX << viewportOrgY << ")";
+#endif
+
+                // If the viewport is set, then a changed window
+                // changes nothing in the bounding box.
+                if (viewportExtIsSet)
+                    break;
+
+                // Collect the maximum width and height.
+                if (abs(windowWidth - windowOrgX) > mMaxWidth)
+                    mMaxWidth = abs(windowWidth - windowOrgX);
+                if (abs(windowHeight - windowOrgY) > mMaxHeight)
+                    mMaxHeight = abs(windowHeight - windowOrgY);
+
+                orgX = windowOrgX;
+                orgY = windowOrgY;
+                extX = windowWidth;
+                extY = windowHeight;
+                //doRecalculateBBox = true;
+            }
+            break;
+
+        case 13: //setViewportOrg
+            {
+                st >> viewportOrgY >> viewportOrgX;
+                bboxRecalculated = false;
+
+#if DEBUG_RECORDS
+                kDebug(31000) << "setViewportOrg" << viewportOrgX << viewportOrgY;
+#endif
+                // Can't do anything without the viewport extensions.
+                if (!viewportExtIsSet)
+                    break;
+
+                // FIXME: Handle the case where the org changes but
+                //        there is no subsequent Ext change (should be
+                //        rather uncommon).
+            }
+            break;
+
+        case 14: //setViewportExt
+            {
+                st >> viewportHeight >> viewportWidth;
+                viewportExtIsSet = true;
+                bboxRecalculated = false;
+
+#if DEBUG_RECORDS
+                kDebug(31000) << "setViewportExt" << viewportWidth << viewportHeight;
+#endif
+                orgX = viewportOrgX;
+                orgY = viewportOrgY;
+                extX = viewportWidth;
+                extY = viewportHeight;
+                //doRecalculateBBox = true;
+            }
+            break;
+
+            // FIXME: Also support:
+            //          ScaleWindowExt, ScaleViewportExt, 
+            //          OffsetWindowOrg, OffsetViewportOrg
+
+            // The following are drawing commands.  It is only when
+            // there is an actual drawing command that we should check
+            // the bounding box. It seems that some WMF files have
+            // lots of changes of the window or viewports but without
+            // any drawing commands in between. These changes should
+            // not affect the bounding box.
+        case 19: // lineTo
+        //case 20: // moveTo
+        case 23: // arc
+        case 24: // ellipse
+        case 26: // pie
+        case 27: // rectangle
+        case 28: // roundRect
+        case 29: // patBlt
+        case 31: // setPixel
+        case 33: // textOut
+        case 34: // bitBlt
+        case 36: // polygon
+        case 37: // polyline
+        //case 38: // escape  FIXME: is this a drawing commmand?
+        case 40: // fillRegion
+        case 41:
+        case 42:
+        case 43:
+        case 44:
+        case 48: // chord
+        case 50: // extTextOut
+        case 56: // polyPolygon
+        case 64: // dibBitBlt
+        case 65: // dibStretchBlt
+        case 67: // stretchDib
+        case 72: // extFloodFill
+            kDebug(31000) << "drawing record: " << (numFunction & 0xff);
+            doRecalculateBBox = true;
+            break;
+
+        default:
+            isOrgOrExt = false;
+        }
+
+        // Recalculate the BBox if it was indicated above that it should be.
+        if (doRecalculateBBox && !bboxRecalculated) {
+            kDebug(31000) << "Recalculating BBox";
+            // If we have a viewport, always use that one.
+            if (viewportExtIsSet) {
+                orgX = viewportOrgX;
+                orgY = viewportOrgY;
+                extX = viewportWidth;
+                extY = viewportHeight;
+            }
+            else {
+                // If there is no defined viewport, then use the window as the fallback viewport.
+                orgX = windowOrgX;
+                orgY = windowOrgY;
+                extX = windowWidth;
+                extY = windowHeight;
+            }
+
+            // If ext < 0, switch the org and org+ext
+            if (extX < 0) {
+                orgX += extX;
+                extX = -extX;
+            }
+            if (extY < 0) {
+                orgY += extY;
+                extY = -extY;
+            }
+
+            // At this point, the ext is always >= 0, i.e. org <= org+ext
+            kDebug(31000) << orgX << orgY << extX << extY;
+            if (orgX < mBBoxLeft)          mBBoxLeft = orgX;
+            if (orgY < mBBoxTop)           mBBoxTop  = orgY;
+            if (orgX + extX > mBBoxRight)  mBBoxRight  = orgX + extX;
+            if (orgY + extY > mBBoxBottom) mBBoxBottom = orgY + extY;
+
+            bboxRecalculated = true;
+        }
+
+#if DEBUG_RECORDS
+        if (isOrgOrExt) {
+            kDebug(31000) << "              mBBoxTop = " << mBBoxTop;
+            kDebug(31000) << "mBBoxLeft = " << mBBoxLeft << "  mBBoxRight = " << mBBoxRight;
+            kDebug(31000) << "           MBBoxBotton = " << mBBoxBottom;
+            kDebug(31000) << "Max width,height = " << mMaxWidth << mMaxHeight;
+        }
+#endif
+
+        mBuffer->seek(filePos + (size << 1));
+    }
+}
+
+
 //-----------------------------------------------------------------------------
 // Metafile painter methods
 
+
 void KoWmfReadPrivate::setWindowOrg(quint32, QDataStream& stream)
 {
     qint16 top, left;
@@ -404,7 +602,9 @@ void KoWmfReadPrivate::setWindowOrg(quint32, QDataStream& stream)
     mReadWmf->setWindowOrg(left, top);
     mWindowLeft = left;
     mWindowTop = top;
-    //kDebug(31000) <<"Org: (" << left <<","  << top <<")";
+#if DEBUG_RECORDS
+    kDebug(31000) <<"Org: (" << left <<","  << top <<")";
+#endif
 }
 
 /*  TODO : deeper look in negative width and height
@@ -416,7 +616,9 @@ void KoWmfReadPrivate::setWindowExt(quint32, QDataStream& stream)
 
     // negative value allowed for width and height
     stream >> height >> width;
-    //kDebug(31000) <<"Ext: (" << width <<","  << height <<")";
+#if DEBUG_RECORDS
+    kDebug(31000) <<"Ext: (" << width <<","  << height <<")";
+#endif
 
     mReadWmf->setWindowExt(width, height);
     mWindowWidth  = width;
@@ -457,6 +659,39 @@ void KoWmfReadPrivate::ScaleWindowExt(quint32, QDataStream &stream)
 }
 
 
+void KoWmfReadPrivate::setViewportOrg(quint32, QDataStream& stream)
+{
+    qint16 top, left;
+
+    stream >> top >> left;
+    mReadWmf->setViewportOrg(left, top);
+    mViewportLeft = left;
+    mViewportTop = top;
+
+#if DEBUG_RECORDS
+    kDebug(31000) <<"Org: (" << left <<","  << top <<")";
+#endif
+}
+
+/*  TODO : deeper look in negative width and height
+*/
+
+void KoWmfReadPrivate::setViewportExt(quint32, QDataStream& stream)
+{
+    qint16 width, height;
+
+    // Negative value allowed for width and height
+    stream >> height >> width;
+#if DEBUG_RECORDS
+    kDebug(31000) <<"Ext: (" << width <<","  << height <<")";
+#endif
+
+    mReadWmf->setViewportExt(width, height);
+    mViewportWidth  = width;
+    mViewportHeight = height;
+}
+
+
 //-----------------------------------------------------------------------------
 // Drawing
 
@@ -1069,6 +1304,7 @@ void KoWmfReadPrivate::createFontIndirect(quint32 size, QDataStream& stream)
         stream >> weight >> property >> arg >> arg;
         stream >> fixedPitch;
 
+        kDebug(31000) << height << width << weight << property;
         // text rotation (in 1/10 degree)
         // TODO: memorisation of rotation in object Font
         mTextRotation = -rotation / 10;
@@ -1185,7 +1421,9 @@ void KoWmfReadPrivate::setLayout(quint32, QDataStream &stream)
     stream >> layout >> reserved;
     mLayout = (WmfLayout)layout;
 
+#if DEBUG_RECORDS
     kDebug(31000) << "setLayout: layout=" << layout;
+#endif
 }
 
 void KoWmfReadPrivate::startDoc(quint32, QDataStream&)
