@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2003 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003-2008 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,22 +29,26 @@ namespace KexiPart
 //! @internal
 class Info::Private
 {
-	public:
-		Private(const KService::Ptr& aPtr);
+public:
+    Private(const KService::Ptr& aPtr);
 
-		//! used in StaticItem class
-		Private();
+    //! used in StaticItem class
+    Private();
 
-		KService::Ptr ptr;
-		QString errorMessage;
-		QString groupName;
-		QCString mimeType;
-		QString itemIcon;
-		QString objectName;
-		int projectPartID;
-		bool broken : 1;
-		bool isVisibleInNavigator : 1;
-		bool idStoredInPartDatabase : 1;
+    KService::Ptr ptr;
+    QString errorMessage;
+    QString groupName;
+//    QString mimeType;
+    QString itemIcon;
+    QString objectName;
+    QString partClass;
+#if 0 //moved as internal to KexiProject
+    int projectPartID;
+#endif
+    bool broken;
+    bool isVisibleInNavigator;
+    bool idStoredInPartDatabase;
+    bool isPropertyEditorAlwaysVisibleInDesignMode;
 };
 }
 
