@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
    Copyright (C) 2002, 2003 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2004 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2010 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -155,11 +155,12 @@ tristate KexiTablePart::rename(KexiPart::Item & item,
     return conn->alterTableName(*sch, newName);
 }
 
-KexiDB::SchemaData*
-KexiTablePart::loadSchemaData(KexiWindow *window, const KexiDB::SchemaData& sdata,
-                              Kexi::ViewMode viewMode)
+KexiDB::SchemaData* KexiTablePart::loadSchemaData(KexiWindow *window, const KexiDB::SchemaData& sdata,
+                              Kexi::ViewMode viewMode, bool *ownedByWindow)
 {
     Q_UNUSED(viewMode);
+    if (ownedByWindow)
+        *ownedByWindow = false;
     return KexiMainWindowIface::global()->project()->dbConnection()->tableSchema(sdata.name());
 }
 
@@ -306,7 +307,8 @@ AboutData( const char *programName,
 #define KEXIPART_EXPORT_FACTORY( libname, partClass, aboutData ) \
   static KexiPart::AboutData * libname ## updateAD(KexiPart::AboutData *ad) \
   { ad->setAppName( #libname ); return ad; } \
-  K_EXPORT_COMPONENT_FACTORY( libname, KGenericFactory<partClass>(libname ## updateAD(#libname)) )
+   K_PLUGIN_FACTORY( libname ## Factory, registerPlugin<partClass>(); )
+   K_EXPORT_PLUGIN( libname ## Factory )
 */
 
 K_EXPORT_KEXI_PLUGIN( KexiTablePart, table )
