@@ -17,18 +17,36 @@
  * Boston, MA 02110-1301, USA.
  */
 #include "KoFormulaShapeFactory.h"
-#include "KoFormulaShape.h"
 
-#include <KoShapeFactoryBase.h>
 #include <klocale.h>
 #include <kdebug.h>
 
+#include <KoShapeFactoryBase.h>
+#include <KoShapeLoadingContext.h>
+#include <KoXmlNS.h>
+
+#include "KoFormulaShape.h"
+
+
 KoFormulaShapeFactory::KoFormulaShapeFactory( QObject *parent )
     : KoShapeFactoryBase( parent, KoFormulaShapeId, i18n( "Formula" ) )
 {
     setToolTip(i18n( "A formula"));
     setIcon( "x-shape-formula" );
-    setOdfElementNames( "http://www.w3.org/1998/Math/MathML", QStringList("math") );
+
+    // The following lines let the formula shape load both embedded and
+    // inline formulas.
+    //
+    // The line below tells the shape registry which XML elements that
+    // the shape supports.
+    //
+    // FIXME: Find out if inline formulas are supported by ODF.
+
+    QList<QPair<QString, QStringList> > elementNamesList;
+    elementNamesList.append(qMakePair(QString(KoXmlNS::draw), QStringList("object")));
+    elementNamesList.append(qMakePair(QString(KoXmlNS::math), QStringList("math")));
+    setOdfElements(elementNamesList);
+
     setLoadingPriority( 1 );
 /*    KoShapeTemplate t;
     t.id = KoFormulaShapeId;
@@ -43,17 +61,26 @@ KoFormulaShapeFactory::KoFormulaShapeFactory( QObject *parent )
 KoFormulaShapeFactory::~KoFormulaShapeFactory()
 {}
 
-KoShape *KoFormulaShapeFactory::createDefaultShape(KoResourceManager *) const
+KoShape *KoFormulaShapeFactory::createDefaultShape(KoResourceManager *resourceManager) const
 {
-    KoFormulaShape* formula = new KoFormulaShape();
+    KoFormulaShape* formula = new KoFormulaShape(resourceManager);
     formula->setShapeId( KoFormulaShapeId );
     return formula;
 }
 
-bool KoFormulaShapeFactory::supports(const KoXmlElement& e) const
+bool KoFormulaShapeFactory::supports(const KoXmlElement& e, KoShapeLoadingContext &context) const
 {
-    kDebug() << e.nodeName() << " - "<< e.namespaceURI();
-    return ( e.nodeName() == "math" ) && ( e.namespaceURI() == "http://www.w3.org/1998/Math/MathML" );
+    Q_UNUSED(context);
+    bool retval = ((e.localName() == "math"
+                    && e.namespaceURI() == KoXmlNS::math)
+                   || (e.localName() == "object"
+                       && e.namespaceURI() == KoXmlNS::draw));
+
+    // Should be 39001 (kformula) instead of 31000 (koffice)
+    //kDebug(31000) << e.nodeName() << " - "<< e.namespaceURI(); 
+    //kDebug(31000) << "Return value = " << retval;
+
+    return retval;
 }
 
 
