@@ -52,6 +52,7 @@ class DateTime;
 class Project;
 class Schedule;
 class XMLLoaderObject;
+class AppointmentIntervalList;
 
 class KPLATOKERNEL_EXPORT DateTimeInterval : public QPair<DateTime, DateTime>
 {
@@ -180,15 +181,14 @@ public:
     bool load( KoXmlElement &element, XMLLoaderObject &status );
     void save(QDomElement &element) const;
 
-    const QList<TimeInterval*> &workingIntervals() const { return m_workingIntervals; }
-    QList<TimeInterval*> workingIntervals() { return m_workingIntervals; }
+    QList<TimeInterval*> timeIntervals() const { return m_timeIntervals; }
     void addInterval( const QTime &t1, int length ) { addInterval( new TimeInterval( t1, length ) ); }
     void addInterval(TimeInterval *interval);
     void addInterval(TimeInterval interval) { addInterval(new TimeInterval(interval)); }
-    void clearIntervals() { m_workingIntervals.clear(); }
+    void clearIntervals() { m_timeIntervals.clear(); }
     void setIntervals(QList<TimeInterval*> intervals) { 
-        m_workingIntervals.clear();
-        m_workingIntervals = intervals;
+        m_timeIntervals.clear();
+        m_timeIntervals = intervals;
     }
     void removeInterval( TimeInterval *interval );
     TimeInterval *intervalAt( int index ) const;
@@ -200,6 +200,9 @@ public:
     int state() const { return m_state; }
     void setState(int state) { m_state = state; }
 
+    DateTime start( const KDateTime::Spec &spec = KDateTime::Spec( KDateTime::LocalZone ) ) const;
+    DateTime end( const KDateTime::Spec &spec = KDateTime::Spec( KDateTime::LocalZone ) ) const;
+
     bool operator==(const CalendarDay *day) const;
     bool operator==(const CalendarDay &day) const;
     bool operator!=(const CalendarDay *day) const;
@@ -272,7 +275,7 @@ private:
     Calendar *m_calendar;
     QDate m_date; //NOTE: inValid if used for weekdays
     int m_state;
-    QList<TimeInterval*> m_workingIntervals;
+    QList<TimeInterval*> m_timeIntervals;
 
 #ifndef NDEBUG
 public:
@@ -391,7 +394,7 @@ public:
      * Removes myself from current parent and
      * inserts myself as child to new parent.
      */
-    void setParentCal(Calendar *parent);
+    void setParentCal( Calendar *parent, int pos = -1 );
     
     bool isChildOf( const Calendar *cal ) const;
     
@@ -402,7 +405,7 @@ public:
     void setId(const QString& id);
     
     const QList<Calendar*> &calendars() const { return m_calendars; }
-    void addCalendar( Calendar *calendar );
+    void addCalendar( Calendar *calendar, int pos = -1 );
     void takeCalendar( Calendar *calendar );
     int indexOf( const Calendar *calendar ) const;
     /// Return number of children
@@ -450,6 +453,12 @@ public:
     void setParentId(const QString& id) { m_parentId = id; }
     bool hasParent(Calendar *cal);
 
+    /**
+     * Returns the work intervals in the interval from @p start to @p end
+     * Sets the load of each interval to @p load
+     */
+    AppointmentIntervalList workIntervals(const DateTime &start, const DateTime &end, double load) const;
+
     /**
      * Returns the amount of 'worktime' that can be done in the
      * interval from @p start to @p end
@@ -499,6 +508,9 @@ public:
     void setDefault( bool on );
     bool isDefault() const { return m_default; }
     
+    int cacheVersion() const;
+    void incCacheVersion();
+
 signals:
     void changed( Calendar* );
     void changed( CalendarDay* );
@@ -562,6 +574,7 @@ private:
     
     KDateTime::Spec m_spec;
     bool m_default; // this is the default calendar, only used for save/load
+    int m_cacheversion; // incremented every time a calendar is changed
     
 #ifndef NDEBUG
 public:
@@ -572,7 +585,7 @@ public:
 class KPLATOKERNEL_EXPORT StandardWorktime
 {
 public:
-    StandardWorktime( Project *project = 0 );
+    explicit StandardWorktime( Project *project = 0 );
     StandardWorktime(StandardWorktime* worktime);
     ~StandardWorktime();
 
@@ -614,7 +627,7 @@ public:
     /// Set the work time of a normal day
     void setDay(double hours) { m_day = Duration(hours, Duration::Unit_h); changed(); }
     
-    QList<double> scales() const;
+    QList<qint64> scales() const;
 
     bool load( KoXmlElement &element, XMLLoaderObject &status );
     void save(QDomElement &element) const;
