@@ -502,9 +502,8 @@ void CostBreakdownItemModel::slotAccountRemoved( const Account *account )
     endRemoveRows();
 }
 
-void CostBreakdownItemModel::slotNodeChanged( Node *node )
+void CostBreakdownItemModel::slotDataChanged()
 {
-    Q_UNUSED(node);
     fetchData();
     foreach ( Account *a, m_plannedCostMap.keys() ) {
         QModelIndex idx1 = index( a );
@@ -526,9 +525,13 @@ void CostBreakdownItemModel::setProject( Project *project )
         disconnect( acc, SIGNAL( accountRemoved( const Account* ) ), this, SLOT( slotAccountRemoved( const Account* ) ) );
         disconnect( acc, SIGNAL( accountToBeRemoved( const Account* ) ), this, SLOT( slotAccountToBeRemoved( const Account* ) ) );
 
-        disconnect( m_project , SIGNAL( nodeChanged( Node* ) ), this, SLOT( slotNodeChanged( Node* ) ) );
-        disconnect( m_project , SIGNAL( nodeAdded( Node* ) ), this, SLOT( slotNodeChanged( Node* ) ) );
-        disconnect( m_project , SIGNAL( nodeRemoved( Node* ) ), this, SLOT( slotNodeChanged( Node* ) ) );
+        disconnect( m_project , SIGNAL( nodeChanged( Node* ) ), this, SLOT( slotDataChanged() ) );
+        disconnect( m_project , SIGNAL( nodeAdded( Node* ) ), this, SLOT( slotDataChanged() ) );
+        disconnect( m_project , SIGNAL( nodeRemoved( Node* ) ), this, SLOT( slotDataChanged() ) );
+
+        disconnect( m_project , SIGNAL( resourceChanged( Resource* ) ), this, SLOT( slotDataChanged() ) );
+        disconnect( m_project , SIGNAL( resourceAdded( const Resource* ) ), this, SLOT( slotDataChanged() ) );
+        disconnect( m_project , SIGNAL( resourceRemoved( const Resource* ) ), this, SLOT( slotDataChanged() ) );
     }
     m_project = project;
     if ( project ) {
@@ -542,9 +545,13 @@ void CostBreakdownItemModel::setProject( Project *project )
         connect( acc, SIGNAL( accountRemoved( const Account* ) ), this, SLOT( slotAccountRemoved( const Account* ) ) );
         connect( acc, SIGNAL( accountToBeRemoved( const Account* ) ), this, SLOT( slotAccountToBeRemoved( const Account* ) ) );
 
-        connect( project , SIGNAL( nodeChanged( Node* ) ), this, SLOT( slotNodeChanged( Node* ) ) );
-        connect( project , SIGNAL( nodeAdded( Node* ) ), this, SLOT( slotNodeChanged( Node* ) ) );
-        connect( project , SIGNAL( nodeRemoved( Node* ) ), this, SLOT( slotNodeChanged( Node* ) ) );
+        connect( m_project , SIGNAL( nodeChanged( Node* ) ), this, SLOT( slotDataChanged() ) );
+        connect( m_project , SIGNAL( nodeAdded( Node* ) ), this, SLOT( slotDataChanged() ) );
+        connect( m_project , SIGNAL( nodeRemoved( Node* ) ), this, SLOT( slotDataChanged() ) );
+
+        connect( m_project , SIGNAL( resourceChanged( Resource* ) ), this, SLOT( slotDataChanged() ) );
+        connect( m_project , SIGNAL( resourceAdded( const Resource* ) ), this, SLOT( slotDataChanged() ) );
+        connect( m_project , SIGNAL( resourceRemoved( const Resource* ) ), this, SLOT( slotDataChanged() ) );
     }
 }
 
