@@ -168,9 +168,13 @@ QImage KisBaseNode::createThumbnail(qint32 w, qint32 h)
 
 }
 
-bool KisBaseNode::visible() const
+bool KisBaseNode::visible(bool recursive) const
 {
-    return m_d->properties.boolProperty("visible", true);
+    bool isVisible = m_d->properties.boolProperty("visible", true);
+    KisBaseNodeSP parentNode = parentCallback();
+
+    return recursive && isVisible && parentNode ?
+        parentNode->visible() : isVisible;
 }
 
 void KisBaseNode::setVisible(bool visible)
@@ -195,15 +199,17 @@ bool KisBaseNode::systemLocked() const
     return m_d->systemLocked;
 }
 
-void KisBaseNode::setSystemLocked(bool locked)
+void KisBaseNode::setSystemLocked(bool locked, bool update)
 {
     m_d->systemLocked = locked;
-    emit(systemLockingChanged(locked));
+    if (update) {
+        emit(systemLockingChanged(locked));
+    }
 }
 
 bool KisBaseNode::isEditable() const
 {
-    return (visible() && !userLocked() && !systemLocked());
+    return (visible(true) && !userLocked() && !systemLocked());
 }
 
 #include "kis_base_node.moc"
