@@ -43,26 +43,31 @@
 KisDynaPaintOp::KisDynaPaintOp(const KisDynaPaintOpSettings *settings, KisPainter * painter, KisImageWSP image)
         : KisPaintOp(painter)
         , m_settings(settings)
-        , m_image(image)
 {
-    m_dynaBrush.setImage(image);
+    if (image){
+        m_dynaBrush.setCanvasSize(image->width(), image->height());
+    }else{
+        // some dummy values for scratchpad 
+        m_dynaBrush.setCanvasSize(1000, 1000);
+    }
 
     m_properties.initWidth = settings->getDouble(DYNA_WIDTH);
     m_properties.action = settings->getDouble(DYNA_ACTION);
     m_properties.mass = settings->getDouble(DYNA_MASS);
     m_properties.drag = settings->getDouble(DYNA_DRAG);
-    m_properties.xAngle = settings->getDouble(DYNA_X_ANGLE);
-    m_properties.yAngle = settings->getDouble(DYNA_Y_ANGLE);
+
+    double angle = settings->getDouble(DYNA_ANGLE);
+    m_properties.xAngle = cos(angle * M_PI/180.0);
+    m_properties.yAngle = sin(angle * M_PI/180.0);
+
     m_properties.widthRange = settings->getDouble(DYNA_WIDTH_RANGE);
-    m_properties.circleRadius = settings->getInt(DYNA_CIRCLE_RADIUS);
+    m_properties.diameter = settings->getInt(DYNA_DIAMETER);
     m_properties.lineCount = settings->getInt(DYNA_LINE_COUNT);
     m_properties.lineSpacing = settings->getDouble(DYNA_LINE_SPACING);
     m_properties.enableLine = settings->getBool(DYNA_ENABLE_LINE);
     m_properties.useTwoCircles = settings->getBool(DYNA_USE_TWO_CIRCLES);
     m_properties.useFixedAngle = settings->getBool(DYNA_USE_FIXED_ANGLE);
     
-    settings->dump();
-    
     m_dynaBrush.setProperties( &m_properties );
 }
 
@@ -73,7 +78,6 @@ KisDynaPaintOp::~KisDynaPaintOp()
 KisDistanceInformation KisDynaPaintOp::paintLine(const KisPaintInformation &pi1, const KisPaintInformation &pi2, const KisDistanceInformation& savedDist)
 {
     Q_UNUSED(savedDist);
-    if (!m_image) return KisDistanceInformation();
     if (!painter()) return KisDistanceInformation();
 
     if (!m_dab) {
@@ -100,8 +104,8 @@ KisDistanceInformation KisDynaPaintOp::paintLine(const KisPaintInformation &pi1,
     return KisDistanceInformation(0, dragVec.norm());
 }
 
-double KisDynaPaintOp::paintAt(const KisPaintInformation& info)
+qreal KisDynaPaintOp::paintAt(const KisPaintInformation& info)
 {
-    Q_UNUSED(info);
-    return 1.0;
+    KisDistanceInformation di(0.0,1.0);
+    return paintLine(info, info, di).spacing;
 }
