@@ -41,6 +41,7 @@ KoColor KisPressureDarkenOption::apply(KisPainter * painter, const KisPaintInfor
     // Darken docs aren't really clear about what exactly the amount param can have as value...
     quint32 darkenAmount = (qint32)(255  - 75 * computeValue(info));
     KoColorTransformation* darkenTransformation  = darkened.colorSpace()->createDarkenAdjustment(darkenAmount, false, 0.0);
+    if(!darkenTransformation) return origColor;
     darkenTransformation ->transform(painter->paintColor().data(), darkened.data(), 1);
     painter->setPaintColor(darkened);
     delete darkenTransformation;
@@ -54,7 +55,7 @@ void KisPressureDarkenOption::apply(KisColorSource* colorSource, const KisPaintI
     
     quint32 darkenAmount = (qint32)(255  - 75 * computeValue(info));
     KoColorTransformation* darkenTransformation  = colorSource->colorSpace()->createDarkenAdjustment(darkenAmount, false, 0.0);
-    
+    if(!darkenTransformation) return;
     colorSource->applyColorTransformation(darkenTransformation);
 
     delete darkenTransformation;
