@@ -31,7 +31,6 @@ class QComboBox;
 class QGridLayout;
 
 class KoCanvasBase;
-class KoSliderCombo;
 class KisSliderSpinBox;
 
 class KisToolBrush : public KisToolFreehand
@@ -55,12 +54,11 @@ protected:
 private slots:
 
     void timeoutPaint();
-    void slotSetRate(int rate);
     void slotSetSmoothness(int smoothness);
     void slotSetMagnetism(int magnetism);
 
 private:
-
+    bool m_isAirbrushing;
     qint32 m_rate;
     QTimer *m_timer;
     QGridLayout *m_optionLayout;
@@ -68,7 +66,6 @@ private:
     QCheckBox *m_chkAssistant;
     KisSliderSpinBox *m_sliderMagnetism;
     KisSliderSpinBox *m_sliderSmoothness;
-    KisSliderSpinBox  *m_sliderRate;
 };
 
 
