@@ -25,6 +25,7 @@
 #include <QVector>
 
 #include "Region.h"
+#include "kspread_limits.h"
 
 // #define KSPREAD_POINT_STORAGE_HASH
 
@@ -32,6 +33,7 @@ namespace KSpread
 {
 
 /**
+ * \ingroup Storage
  * A custom pointwise storage.
  * Based on a compressed sparse matrix data structure.
  * Usable for any kind of data attached to 2D coordinates.
@@ -159,18 +161,18 @@ public:
      * default object.
      * \return the data at the given coordinate
      */
-    T lookup(int col, int row) const {
+    T lookup(int col, int row, const T& defaultVal = T()) const {
         Q_ASSERT(1 <= col && col <= KS_colMax);
         Q_ASSERT(1 <= row && row <= KS_rowMax);
         // is the row not present?
         if (row > m_rows.count())
-            return T();
+            return defaultVal;
         const QVector<int>::const_iterator cstart(m_cols.begin() + m_rows.value(row - 1));
         const QVector<int>::const_iterator cend((row < m_rows.count()) ? (m_cols.begin() + m_rows.value(row)) : m_cols.end());
         const QVector<int>::const_iterator cit = qBinaryFind(cstart, cend, col);
         // is the col not present?
         if (cit == cend)
-            return T();
+            return defaultVal;
         return m_data.value(m_rows.value(row - 1) + (cit - cstart));
     }
 
@@ -178,19 +180,19 @@ public:
      * Removes data at \p col , \p row .
      * \return the removed data (default data, if none)
      */
-    T take(int col, int row) {
+    T take(int col, int row, const T& defaultVal = T()) {
         Q_ASSERT(1 <= col && col <= KS_colMax);
         Q_ASSERT(1 <= row && row <= KS_rowMax);
         // row's missing?
         if (row > m_rows.count())
-            return T();
+            return defaultVal;
         const int rowStart = (row - 1 < m_rows.count()) ? m_rows.value(row - 1) : m_data.count();
         const int rowLength = (row < m_rows.count()) ? m_rows.value(row) - rowStart : -1;
         const QVector<int> cols = m_cols.mid(rowStart, rowLength);
         QVector<int>::const_iterator cit = qBinaryFind(cols, col);
         // column's missing?
         if (cit == cols.constEnd())
-            return T();
+            return defaultVal;
         const int index = rowStart + (cit - cols.constBegin());
         // save the old data
         const T oldData = m_data[ index ];
@@ -407,14 +409,16 @@ public:
             const QVector<T> data = m_data.mid(rowStart, rowLength);
             // first, iterate over the destination row
             for (int col = cols.count() - 1; col >= 0; --col) {
-                if (cols.value(col) >= rect.left() && cols.value(col) <= rect.right()) {
+                const int column = cols.value(col); // real column value (1...KS_colMax)
+                if (column >= rect.left() && column <= rect.right()) {
                     // save the old data
                     if (row <= rect.bottom())
-                        oldData.append(qMakePair(QPoint(cols.value(col), row), data.value(col)));
+                        oldData.append(qMakePair(QPoint(column, row), data.value(col)));
                     // search
-                    const QVector<int>::const_iterator cstart2((row + rect.height() - 1 < m_rows.count()) ? m_cols.begin() + m_rows.value(row + rect.height() - 1) : m_cols.end());
-                    const QVector<int>::const_iterator cend2(((row + rect.height() < m_rows.count())) ? (m_cols.begin() + m_rows.value(row + rect.height())) : m_cols.end());
-                    const QVector<int>::const_iterator cit2 = qBinaryFind(cstart2, cend2, cols.value(col));
+                    const int srcRow = row + rect.height();
+                    const QVector<int>::const_iterator cstart2((srcRow - 1 < m_rows.count()) ? m_cols.begin() + m_rows.value(srcRow - 1) : m_cols.end());
+                    const QVector<int>::const_iterator cend2((srcRow < m_rows.count()) ? (m_cols.begin() + m_rows.value(srcRow)) : m_cols.end());
+                    const QVector<int>::const_iterator cit2 = qBinaryFind(cstart2, cend2, column);
                     // column's missing?
                     if (cit2 == cend2) {
                         m_cols.remove(rowStart + col);
@@ -437,25 +441,48 @@ public:
                 }
             }
             // last, iterate over the source row
-            const int rowStart2 = (row + rect.height() - 1 < m_rows.count()) ? m_rows.value(row + rect.height() - 1) : m_data.count();
-            const int rowLength2 = (row + rect.height() < m_rows.count()) ? m_rows.value(row + rect.height()) - rowStart2 : -1;
+            const int srcRow = row + rect.height();
+            const int rowStart2 = (srcRow - 1 < m_rows.count()) ? m_rows.value(srcRow - 1) : m_data.count();
+            const int rowLength2 = (srcRow < m_rows.count()) ? m_rows.value(srcRow) - rowStart2 : -1;
             const QVector<int> cols2 = m_cols.mid(rowStart2, rowLength2);
             const QVector<T> data2 = m_data.mid(rowStart2, rowLength2);
+            int offset = 0;
             for (int col = cols2.count() - 1; col >= 0; --col) {
-                if (cols2.value(col) >= rect.left() && cols2.value(col) <= rect.right()) {
+                const int column = cols2.value(col); // real column value (1...KS_colMax)
+                if (column >= rect.left() && column <= rect.right()) {
                     // find the insertion position
                     const QVector<int>::const_iterator cstart((row - 1 < m_rows.count()) ? m_cols.begin() + m_rows.value(row - 1) : m_cols.end());
                     const QVector<int>::const_iterator cend(((row < m_rows.count())) ? (m_cols.begin() + m_rows.value(row)) : m_cols.end());
                     const QVector<int>::const_iterator cit = qUpperBound(cstart, cend, cols2.value(col));
-                    // copy it to its new position
-                    m_data.insert(cit - m_cols.constBegin(), m_data.value(rowStart2 + col));
-                    m_cols.insert(cit - m_cols.constBegin(), m_cols.value(rowStart2 + col));
-                    // remove it from its old position
-                    m_data.remove(rowStart2 + col + 1);
-                    m_cols.remove(rowStart2 + col + 1);
-                    // adjust the offsets of the following rows
-                    for (int r = row; r < row + rect.height(); ++r)
-                        ++m_rows[r];
+                    // Destination column:
+                    const QVector<int>::const_iterator dstcit = qBinaryFind(cols.begin(), cols.end(), column);
+                    if (dstcit != cols.end()) { // destination column exists
+                        // replace the existing destination value
+                        const int dstCol = (dstcit - cols.constBegin());
+                        m_data[rowStart + dstCol] = m_data.value(rowStart2 + col);
+                        // remove it from its old position
+                        m_data.remove(rowStart2 + col + 1);
+                        m_cols.remove(rowStart2 + col + 1);
+                        // The amount of values in the range from the
+                        // destination row to the source row have not changed.
+                        // adjust the offsets of the following rows
+                        for (int r = srcRow; r < m_rows.count(); ++r) {
+                            ++m_rows[r];
+                        }
+                    } else { // destination column does not exist yet
+                        // copy it to its new position
+                        const int dstCol = cit - m_cols.constBegin();
+                        m_data.insert(dstCol, data2.value(col));
+                        m_cols.insert(dstCol, cols2.value(col));
+                        // remove it from its old position
+                        m_data.remove(rowStart2 + col + 1 + offset);
+                        m_cols.remove(rowStart2 + col + 1 + offset);
+                        ++offset;
+                        // adjust the offsets of the following rows
+                        for (int r = row; r < srcRow; ++r) {
+                            ++m_rows[r];
+                        }
+                    }
                 }
             }
         }
