@@ -22,18 +22,10 @@
 #include "TestKspreadCommon.h"
 
 #include <CellStorage.h>
-#include <part/Doc.h> // FIXME detach from part
 #include <Formula.h>
 #include <Map.h>
 #include <Sheet.h>
 
-#include "functions/EngineeringModule.h"
-#include "functions/LogicModule.h"
-#include "functions/MathModule.h"
-#include "functions/StatisticalModule.h"
-#include "functions/TrigonometryModule.h"
-#include "FunctionModuleRegistry.h"
-
 // NOTE: we do not compare the numbers _exactly_ because it is difficult
 // to get one "true correct" expected values for the functions due to:
 //  - different algorithms among spreadsheet programs
@@ -47,7 +39,7 @@ Value TestMathFunctions::TestDouble(const QString& formula, const Value& v2, int
 {
     double epsilon = DBL_EPSILON * pow(10.0, (double)(accuracy));
 
-    Formula f(m_doc->map()->sheet(0));
+    Formula f(m_map->sheet(0));
     QString expr = formula;
     if (expr[0] != '=')
         expr.prepend('=');
@@ -67,13 +59,13 @@ Value TestMathFunctions::TestDouble(const QString& formula, const Value& v2, int
 }
 
 // round to get at most 10-digits number
-static Value RoundNumber(double f)
+inline static Value RoundNumber(double f)
 {
     return Value(ROUND(f));
 }
 
 // round to get at most 10-digits number
-static Value RoundNumber(const Value& v)
+inline static Value RoundNumber(const Value& v)
 {
     if (v.isNumber()) {
         double d = numToDouble(v.asFloat());
@@ -86,7 +78,7 @@ static Value RoundNumber(const Value& v)
 
 Value TestMathFunctions::evaluate(const QString& formula)
 {
-    Formula f(m_doc->map()->sheet(0));
+    Formula f(m_map->sheet(0));
     QString expr = formula;
     if (expr[0] != '=')
         expr.prepend('=');
@@ -103,15 +95,11 @@ Value TestMathFunctions::evaluate(const QString& formula)
 
 void TestMathFunctions::initTestCase()
 {
-    FunctionModuleRegistry::instance()->add(new EngineeringModule(this));
-    FunctionModuleRegistry::instance()->add(new LogicModule(this));
-    FunctionModuleRegistry::instance()->add(new MathModule(this));
-    FunctionModuleRegistry::instance()->add(new StatisticalModule(this));
-    FunctionModuleRegistry::instance()->add(new TrigonometryModule(this));
-    FunctionModuleRegistry::instance()->registerFunctions();
-    m_doc = new Doc();
-    m_doc->map()->addNewSheet();
-    Sheet* sheet = m_doc->map()->sheet(0);
+    FunctionModuleRegistry::instance()->loadFunctionModules();
+
+    m_map = new Map(0 /* no Doc */);
+    m_map->addNewSheet();
+    Sheet* sheet = m_map->sheet(0);
     CellStorage* storage = sheet->cellStorage();
 
     // B3:B7
@@ -126,7 +114,7 @@ void TestMathFunctions::initTestCase()
 
 void TestMathFunctions::cleanupTestCase()
 {
-    delete m_doc;
+    delete m_map;
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////
@@ -142,9 +130,7 @@ void TestMathFunctions::testABS()
     CHECK_EVAL("ABS(2)",   Value(2));
     CHECK_EVAL("ABS(3)",   Value(3));
     CHECK_EVAL("ABS(4)",   Value(4));
-
     CHECK_EVAL("ABS(1/0)", Value::errorDIV0());
-
 }
 
 void TestMathFunctions::testACOS()
@@ -237,24 +223,35 @@ void TestMathFunctions::testBESSELI()
 {
     // ODF-tests
     CHECK_EVAL_SHORT("BESSELI(2;2)",  Value(0.688948));     // TODO expand
+    CHECK_EVAL_SHORT("BESSELI(0.7;3)", Value(0.007367));
+    // alternate function name
+    CHECK_EVAL_SHORT("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETBESSELI(2;2)", Value(0.688948));
 }
 
 void TestMathFunctions::testBESSELJ()
 {
     // ODF-tests
     CHECK_EVAL_SHORT("BESSELJ(1;0)",  Value(0.765198));     // TODO expand
+    CHECK_EVAL_SHORT("BESSELJ(0.89;3)", Value(0.013974));
+    // alternate function name
+    CHECK_EVAL_SHORT("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETBESSELJ(1;0)", Value(0.765198));
 }
 
 void TestMathFunctions::testBESSELK()
 {
     // ODF-tests
     CHECK_EVAL_SHORT("BESSELK(3;0)",  Value(0.03474));      // TODO expand
+    // alternate function name
+    CHECK_EVAL_SHORT("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETBESSELK(3;0)", Value(0.03474));
 }
 
 void TestMathFunctions::testBESSELY()
 {
     // ODF-tests
     CHECK_EVAL_SHORT("BESSELY(1;1)", Value(-0.781213));     // TODO expand
+    CHECK_EVAL_SHORT("BESSELY(4;2)", Value(0.215903595));
+    // alternate function name
+    CHECK_EVAL_SHORT("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETBESSELY(1;1)", Value(-0.781213));
 }
 
 void TestMathFunctions::testCEIL()
@@ -452,6 +449,7 @@ void TestMathFunctions::testFACTDOUBLE()
     CHECK_EVAL("FACTDOUBLE(6)", Value(48));
     CHECK_EVAL("FACTDOUBLE(-1)",        Value::errorNUM());
     CHECK_EVAL("FACTDOUBLE(\"xyzzy\")", Value::errorNUM());
+    CHECK_EVAL("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETFACTDOUBLE(7)", Value(105)); // alternate function name
 }
 
 void TestMathFunctions::testFIB()
@@ -527,6 +525,7 @@ void TestMathFunctions::testGCD()
     CHECK_EVAL("GCD(-2;3)",  Value::errorNUM());
     CHECK_EVAL("GCD(2;-4)",  Value::errorNUM());
     CHECK_EVAL("GCD(-2;-4)", Value::errorNUM());
+    CHECK_EVAL("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETGCD(18;24)", Value(6)); // alternate function name
 }
 
 void TestMathFunctions::testGESTEP()
@@ -567,6 +566,7 @@ void TestMathFunctions::testLCM()
     CHECK_EVAL("LCM(-2;4)",  Value::errorNUM());
     CHECK_EVAL("LCM(2;-4)",  Value::errorNUM());
     CHECK_EVAL("LCM(-2;-4)", Value::errorNUM());
+    CHECK_EVAL("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETLCM(18;12)", Value(36)); // alternate function name
 }
 
 void TestMathFunctions::testLN()
@@ -664,6 +664,16 @@ void TestMathFunctions::testMROUND()
     CHECK_EVAL("=MROUND(1520;100)", Value(1500));
     CHECK_EVAL("=MROUND(1550;100)", Value(1600));
     CHECK_EVAL("=MROUND(41.89;8)",  Value(40));
+    // alternate function name
+    CHECK_EVAL("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETMROUND(1520;100)", Value(1500));
+}
+
+void TestMathFunctions::testMULTINOMIAL()
+{
+    // ODF-tests
+    CHECK_EVAL("=MULTINOMIAL(3;4;5)", Value(27720));
+    // alternate function name
+    CHECK_EVAL("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETMULTINOMIAL(3;4;5)", Value(27720));
 }
 
 void TestMathFunctions::testMUNIT()
@@ -708,6 +718,7 @@ void TestMathFunctions::testQUOTIENT()
     CHECK_EVAL("QUOTIENT(21;-5)",    Value(-4));     //
     CHECK_EVAL("QUOTIENT(-14;5)",    Value(-2));     //
     CHECK_EVAL("QUOTIENT(5;0)" ,     Value::errorDIV0());   //
+    CHECK_EVAL("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETQUOTIENT(14;5)", Value(2)); // alternate function name
 }
 
 void TestMathFunctions::testRADIANS()
@@ -728,6 +739,7 @@ void TestMathFunctions::testRANDBETWEEN()
     CHECK_EVAL("RANDBETWEEN(5;15)<=15", Value(true));     // Must return value in range
     CHECK_EVAL("RANDBETWEEN(15;5)>=5",  Value(true));     // Must return value in range
     CHECK_EVAL("RANDBETWEEN(15;5)<=15", Value(true));     // Must return value in range
+    CHECK_EVAL("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETRANDBETWEEN(8;8)", Value(8)); // alternate function name
 }
 
 void TestMathFunctions::testROUND()
@@ -803,6 +815,7 @@ void TestMathFunctions::testSQRTPI()
     CHECK_EVAL_SHORT("SQRTPI(1)",  Value(1.77245385));       // TODO more digits / The square root of PI
     CHECK_EVAL("SQRTPI(2)",  Value(2.5066282746));     // The square root of 2PI
     CHECK_EVAL("SQRTPI(-4)", Value::errorNUM());       // The argument must be non-negative
+    CHECK_EVAL("COM.SUN.STAR.SHEET.ADDIN.ANALYSIS.GETSQRTPI(2)", Value(2.5066282746)); // alternate function name
 }
 
 void TestMathFunctions::testSUBTOTAL()
