@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2009 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2006-2010 Thomas Zander <zander@kde.org>
  * Copyright (C) 2008 Pierre Ducroquet <pinaraf@pinaraf.info>
  *
  * This library is free software; you can redistribute it and/or
@@ -26,6 +26,7 @@
 #include "KWPage.h"
 #include "KWCopyShape.h"
 #include "KWDocument.h"
+#include "KWPageBackground.h"
 
 #include <KoShapeRegistry.h>
 #include <KoShapeFactoryBase.h>
@@ -41,6 +42,7 @@ KWFrameLayout::KWFrameLayout(const KWPageManager *pageManager, const QList<KWFra
         : m_pageManager(pageManager),
         m_frameSets(frameSets),
         m_maintext(0),
+        m_backgroundFrameSet(0),
         m_document(0),
         m_setup(false)
 {
@@ -67,27 +69,77 @@ void KWFrameLayout::createNewFramesForPage(int pageNumber)
     if (shouldHaveHeaderOrFooter(pageNumber, true, &origin)) {
         allHFTypes.removeAll(origin);
         KWTextFrameSet *fs = getOrCreate(origin, page);
-        if (!hasFrameOn(fs, pageNumber))
+        if (!frameOn(fs, pageNumber))
             createCopyFrame(fs, page);
     }
     if (shouldHaveHeaderOrFooter(pageNumber, false, &origin)) {
         allHFTypes.removeAll(origin);
         KWTextFrameSet *fs = getOrCreate(origin, page);
-        if (!hasFrameOn(fs, pageNumber))
+        if (!frameOn(fs, pageNumber))
             createCopyFrame(fs, page);
     }
 
+    if (page.pageStyle().background()) {
+        // create page background
+        if (!m_backgroundFrameSet) {
+            m_backgroundFrameSet = new KWFrameSet(KWord::BackgroundFrameSet);
+            m_backgroundFrameSet->setName("backgroundFrames");
+            emit newFrameSet(m_backgroundFrameSet);
+            Q_ASSERT(m_frameSets.contains(m_backgroundFrameSet)); // the emit should have made that so :)
+        }
+        KWFrame *background = frameOn(m_backgroundFrameSet, pageNumber);
+        if (background == 0) {
+            KoShape *shape = new KWPageBackground();
+            shape->setPosition(QPointF(0, page.offsetInDocument()));
+            background = new KWFrame(shape, m_backgroundFrameSet);
+            background->setTextRunAround(KWord::RunThrough);
+            // TODO pagespread
+        }
+        background->shape()->setBackground(page.pageStyle().background());
+    } else {
+        // check if there is a frame, if so, delete it, we don't need it.
+        KWFrame *background = frameOn(m_backgroundFrameSet, pageNumber);
+        if (background)
+            delete background->shape();
+    }
+
     // delete headers/footer frames that are not needed on this page
     foreach (KWFrame *frame, framesInPage(page.rect())) {
-        KWTextFrameSet *tfs = dynamic_cast<KWTextFrameSet*>(frame->frameSet());
-        if (tfs && allHFTypes.contains(tfs->textFrameSetType())) {
+        if (frame->frameSet()->type() != KWord::TextFrameSet)
+            continue;
+        KWTextFrameSet *tfs = static_cast<KWTextFrameSet*>(frame->frameSet());
+        if (tfs && (allHFTypes.contains(tfs->textFrameSetType())
+                || (tfs->pageStyle() != page.pageStyle() && KWord::isHeaderFooter(tfs)))) {
             tfs->removeFrame(frame);
-            delete frame;
+            delete frame->shape();
+        }
+    }
+
+    // create main text frame. All columns of them.
+    if (page.pageStyle().hasMainTextFrame()) {
+        int columns = page.pageStyle().columns().columns;
+        KWTextFrameSet *fs = getOrCreate(KWord::MainTextFrameSet, page);
+        QRectF rect(QPointF(0, page.offsetInDocument()),
+                    QSizeF(page.width(), page.height()));
+        if (page.pageSide() == KWPage::PageSpread)
+            rect.setWidth(rect.width() / 2);
+        foreach (KWFrame *frame, framesInPage(rect)) {
+            if (frame->frameSet() == fs) {
+                columns--;
+                if (columns < 0) {
+                    fs->removeFrame(frame);
+                    delete frame->shape();
+                }
+            }
+        }
+        while (columns > 0) {
+            new KWTextFrame(createTextShape(page), fs);
+            columns--;
         }
     }
 
     if (page.pageSide() == KWPage::PageSpread) {
-        // inline helper method
+        // inline helper class
         class PageSpreadShapeFactory
         {
         public:
@@ -108,12 +160,12 @@ void KWFrameLayout::createNewFramesForPage(int pageNumber)
         PageSpreadShapeFactory factory(this);
         if (shouldHaveHeaderOrFooter(pageNumber + 1, true, &origin)) {
             KWTextFrameSet *fs = getOrCreate(origin, m_pageManager->page(pageNumber + 1));
-            if (!hasFrameOn(fs, pageNumber + 1))
+            if (!frameOn(fs, pageNumber + 1))
                 factory.create(page, fs);
         }
         if (shouldHaveHeaderOrFooter(pageNumber + 1, false, &origin)) {
             KWTextFrameSet *fs = getOrCreate(origin, m_pageManager->page(pageNumber + 1));
-            if (!hasFrameOn(fs, pageNumber + 1))
+            if (!frameOn(fs, pageNumber + 1))
                 factory.create(page, fs);
         }
         if (page.pageStyle().hasMainTextFrame()) {
@@ -137,29 +189,6 @@ void KWFrameLayout::createNewFramesForPage(int pageNumber)
         }
     }
 
-    // create main text frame. All columns of them.
-    if (page.pageStyle().hasMainTextFrame()) {
-        int columns = page.pageStyle().columns().columns;
-        KWTextFrameSet *fs = getOrCreate(KWord::MainTextFrameSet, page);
-        QRectF rect(QPointF(0, page.offsetInDocument()),
-                    QSizeF(page.width(), page.height()));
-        if (page.pageSide() == KWPage::PageSpread)
-            rect.setWidth(rect.width() / 2);
-        foreach (KWFrame *frame, framesInPage(rect)) {
-            if (frame->frameSet() == fs) {
-                columns--;
-                if (columns < 0) {
-                    fs->removeFrame(frame);
-                    delete frame;
-                }
-            }
-        }
-        while (columns > 0) {
-            new KWTextFrame(createTextShape(page), fs);
-            columns--;
-        }
-    }
-
     bool odd = false; // an odd number of pages back, so frameOnBothSheets matters
     for (int i = pageNumber - 2; i < pageNumber; i++) {
         if (i < m_pageManager->begin().pageNumber()) {
@@ -175,17 +204,18 @@ void KWFrameLayout::createNewFramesForPage(int pageNumber)
                     frame->newFrameBehavior() == KWord::CopyNewFrame))
                 continue;
 
+            if (KWord::isAutoGenerated(frame->frameSet()))
+                continue; // these are copied above already.
             KWFrame *f;
             KWTextFrameSet *tfs = dynamic_cast<KWTextFrameSet*>(frame->frameSet());
-            if (tfs) {
-                if (tfs->textFrameSetType() != KWord::OtherTextFrameSet)
-                    continue; // these are copied above already.
+            if (tfs && frame->newFrameBehavior() != KWord::CopyNewFrame) {
                 f = new KWTextFrame(createTextShape(page), tfs);
             } else {
                 Q_ASSERT(frame->newFrameBehavior() == KWord::CopyNewFrame);
                 Q_ASSERT(frame->frameSet());
                 Q_ASSERT(frame->frameSet()->frameCount() > 0);
-                f = new KWFrame(new KWCopyShape(frame->frameSet()->frames().first()->shape(), m_pageManager), frame->frameSet());
+                f = new KWFrame(new KWCopyShape(frame->frameSet()->frames().first()->shape(),
+                            m_pageManager), frame->frameSet());
             }
             const qreal y = frame->shape()->position().y();
             qreal offsetFromPage = y - pageRect.top();
@@ -212,29 +242,27 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
     Q_ASSERT(page.isValid());
 
     /* +-----------------+
-       |  0              | <- m_pageStyle->pageLayout()->topMargin + d:o->topPadding
+       |  0              | <- pageStyle->pageLayout()->topMargin + layout->topPadding
        |  1  [ header ]  |
-       |  2              | <- m_pageStyle->headerDistance()
+       |  2              | <- pageStyle->headerDistance()
        |  3  [ maintxt ] |
-       |  4              | <- m_pageStyle->endNoteDistance()
+       |  4              | <- pageStyle->endNoteDistance()
        |  5  [ endnote ] |
-       |  6              | <- m_pageStyle->footnoteDistance()
-       |  7 [ footnote ] |
-       |  8              | <- m_pageStyle->footerDistance()
-       |  9  [ footer ]  |
-       | 10               | <- m_pageStyle->pageLayout()->bottomMargin + d:o->bottomPadding
+       |  6              | <- pageStyle->footerDistance()
+       |  7  [ footer ]  |
+       |  8              | <- pageStyle->pageLayout()->bottomMargin + layout->bottomPadding
        +-----------------+ */
 
     // Create some data structures used for the layouting of the frames later
     int minZIndex = INT_MAX;
-    qreal requestedHeight[11], minimumHeight[11], resultingPositions[11];
-    for (int i = 0; i < 11; i++) { // zero fill.
+    qreal requestedHeight[9], minimumHeight[9], resultingPositions[9];
+    for (int i = 0; i < 9; i++) { // zero fill.
         requestedHeight[i] = 0;
         minimumHeight[i] = 0;
         resultingPositions[i] = 0;
     }
     minimumHeight[0] = page.topMargin() + page.topPadding();
-    minimumHeight[10] = page.bottomMargin() + page.bottomPadding();
+    minimumHeight[8] = page.bottomMargin() + page.bottomPadding();
 
     KoPageLayout layout = page.pageStyle().pageLayout();
     layout.leftMargin = page.leftMargin();
@@ -244,47 +272,62 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
     qreal left = 0, width = page.width();
     if (page.pageSide() == KWPage::PageSpread) {
         width /= 2;
-        if (page.pageNumber() != pageNumber) { // doing the 'right' one
+        layout.leftMargin = page.pageEdgeMargin();
+        layout.rightMargin = page.marginClosestBinding();
+        if (page.pageNumber() != pageNumber) { // doing the 'right' part
             left = width;
-            qreal x = layout.leftMargin; // swap margins
-            layout.leftMargin = layout.rightMargin;
-            layout.rightMargin = x;
-            x = layout.leftPadding; // swap paddings
-            layout.leftPadding = layout.rightPadding;
-            layout.rightPadding = x;
+            qSwap(layout.leftMargin, layout.rightMargin);
+            qSwap(layout.leftPadding, layout.rightPadding);
         }
     }
     qreal textWidth = width - layout.leftMargin - layout.rightMargin
                             - layout.leftPadding - layout.rightPadding;
 
     KWPageStyle pageStyle = page.pageStyle();
-    const int columns = pageStyle.hasMainTextFrame() ? pageStyle.columns().columns * (page.pageSide() == KWPage::PageSpread ? 2 : 1) : 0;
+    const int columns = pageStyle.hasMainTextFrame() ? pageStyle.columns().columns : 0;
     int columnsCount = columns;
-    KWTextFrame **main, *footer = 0, *endnote = 0, *header = 0, *footnote = 0;
+    KWTextFrame **main;
+    KWTextFrame *footer = 0, *endnote = 0, *header = 0;
+    KWFrame *pageBackground = 0;
     main = new KWTextFrame*[columnsCount];
     if (columns > 0)
         main[0] = 0;
     QRectF pageRect(left, page.offsetInDocument(), width, page.height());
     foreach (KWFrame *frame, framesInPage(pageRect)) {
-        KWTextFrameSet *textFrameSet = dynamic_cast<KWTextFrameSet*>(frame->frameSet());
-        if (textFrameSet == 0 || textFrameSet->textFrameSetType() == KWord::OtherTextFrameSet)
+        KWTextFrameSet *textFrameSet = 0;
+        switch (frame->frameSet()->type()) {
+        case KWord::BackgroundFrameSet:
+            pageBackground = frame;
+            continue;
+        case KWord::TextFrameSet:
+            textFrameSet = static_cast<KWTextFrameSet*>(frame->frameSet());
+            if (textFrameSet->textFrameSetType() == KWord::OtherTextFrameSet) {
+                minZIndex = qMin(minZIndex, frame->shape()->zIndex());
+                continue;
+            }
+            break;
+        case KWord::OtherFrameSet:
             minZIndex = qMin(minZIndex, frame->shape()->zIndex());
-        if (textFrameSet == 0) continue;
+            continue;
+        }
+        Q_ASSERT(textFrameSet);
         switch (textFrameSet->textFrameSetType()) {
         case KWord::OddPagesHeaderTextFrameSet:
         case KWord::EvenPagesHeaderTextFrameSet: {
             header = static_cast<KWTextFrame *>(frame);
-            minimumHeight[1] = 10;
+            minimumHeight[1] = qMax((qreal)10, page.pageStyle().headerMinimumHeight());
             requestedHeight[1] = static_cast<KWTextFrame *>(textFrameSet->frames().first())->minimumFrameHeight();
-            minimumHeight[2] = page.pageStyle().headerDistance();
+            if (minimumHeight[1] < page.pageStyle().headerDistance())
+                minimumHeight[2] = page.pageStyle().headerDistance() - minimumHeight[1];
             break;
         }
         case KWord::OddPagesFooterTextFrameSet:
         case KWord::EvenPagesFooterTextFrameSet: {
             footer = static_cast<KWTextFrame *>(frame);
-            minimumHeight[9] = 10;
-            requestedHeight[9] = static_cast<KWTextFrame *>(textFrameSet->frames().first())->minimumFrameHeight();
-            minimumHeight[8] = page.pageStyle().headerDistance();
+            minimumHeight[7] = qMax((qreal)10, page.pageStyle().footerMinimumHeight());
+            requestedHeight[7] = static_cast<KWTextFrame *>(textFrameSet->frames().first())->minimumFrameHeight();
+            if(minimumHeight[7] < page.pageStyle().footerDistance())
+                minimumHeight[6] = page.pageStyle().footerDistance() - minimumHeight[7];
             break;
         }
         case KWord::MainTextFrameSet: {
@@ -303,27 +346,31 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
             requestedHeight[3] = -1; // rest
             break;
         }
-        // TODO end + foot note frameset
+        // TODO endnote frameset
         default:;
         }
     }
     if (minZIndex < INT_MAX) {
         --minZIndex;
+        if (endnote)
+            endnote->shape()->setZIndex(minZIndex--);
         for (int i = 0; i < columns; ++i)
             main[i]->shape()->setZIndex(minZIndex);
         if (footer)
-            footer->shape()->setZIndex(minZIndex);
-        if (endnote)
-            endnote->shape()->setZIndex(minZIndex);
+            footer->shape()->setZIndex(--minZIndex);
         if (header)
-            header->shape()->setZIndex(minZIndex);
-        if (footnote)
-            footnote->shape()->setZIndex(minZIndex);
+            header->shape()->setZIndex(--minZIndex);
+        if (pageBackground) {
+            KoShape *bs = pageBackground->shape();
+            bs->setZIndex(--minZIndex);
+            bs->setSize(pageRect.size());
+            bs->setPosition(pageRect.topLeft());
+        }
     }
 
     // spread space across items.
     qreal heightLeft = page.height();
-    for (int i = 0; i < 11; i++)
+    for (int i = 0; i < 9; i++)
         heightLeft -= qMax(minimumHeight[i], requestedHeight[i]);
     if (heightLeft >= 0) { // easy; plenty of space
         if (minimumHeight[5] > 0) // if we have an endnote
@@ -331,7 +378,7 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
         else
             minimumHeight[3] += heightLeft; // add space to main text frame
         qreal y = page.offsetInDocument();
-        for (int i = 0; i < 11; i++) {
+        for (int i = 0; i < 9; i++) {
             resultingPositions[i] = y;
             y += qMax(minimumHeight[i], requestedHeight[i]);
         }
@@ -339,12 +386,11 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
         // for situations where the header + footer are too big to fit together with a
         // minimum sized main text frame.
         minimumHeight[5] = 0; // no end note
-        minimumHeight[7] = 0; // no footnote
         heightLeft = page.height();
-        for (int i = 0; i < 11; i++)
+        for (int i = 0; i < 9; i++)
             heightLeft -= minimumHeight[i];
         qreal y = page.offsetInDocument();
-        for (int i = 0; i < 11; i++) {
+        for (int i = 0; i < 9; i++) {
             resultingPositions[i] = y;
             qreal row = minimumHeight[i];
             if (requestedHeight[i] > row) {
@@ -384,14 +430,6 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
         }
         delete[] points;
     }
-#ifdef __GNUC__
-#warning can never reach that code as footnote is a constant 0
-#endif
-    if (footnote) {
-        footnote->shape()->setPosition(
-            QPointF(left + layout.leftMargin + layout.leftPadding, resultingPositions[7]));
-        footnote->shape()->setSize(QSizeF(textWidth, resultingPositions[8] - resultingPositions[7]));
-    }
     if (endnote) {
         endnote->shape()->setPosition(
             QPointF(left + layout.leftMargin + layout.leftPadding, resultingPositions[5]));
@@ -404,11 +442,16 @@ void KWFrameLayout::layoutFramesOnPage(int pageNumber)
     }
     if (footer) {
         footer->shape()->setPosition(
-            QPointF(left + layout.leftMargin + layout.leftPadding, resultingPositions[9]));
-        footer->shape()->setSize(QSizeF(textWidth, resultingPositions[10] - resultingPositions[9]));
+            QPointF(left + layout.leftMargin + layout.leftPadding, resultingPositions[7]));
+        footer->shape()->setSize(QSizeF(textWidth, resultingPositions[8] - resultingPositions[7]));
+    }
+    if (pageBackground) {
+        pageBackground->shape()->setPosition(
+            QPointF(left, page.offsetInDocument()));
+        pageBackground->shape()->setSize(QSizeF(width, page.height()));
     }
     delete [] main;
-// TODO footnotes, endnotes
+// TODO endnotes
 }
 
 bool KWFrameLayout::shouldHaveHeaderOrFooter(int pageNumber, bool header, KWord::TextFrameSetType *origin)
@@ -433,7 +476,7 @@ bool KWFrameLayout::shouldHaveHeaderOrFooter(int pageNumber, bool header, KWord:
     return true;
 }
 
-QList<KWFrame *> KWFrameLayout::framesInPage(const QRectF &page)
+QList<KWFrame *> KWFrameLayout::framesInPage(const QRectF &page) const
 {
     // hopefully replaced with a tree
     QList<KWFrame*> answer;
@@ -469,9 +512,7 @@ KWTextFrameSet *KWFrameLayout::getOrCreate(KWord::TextFrameSetType type, const K
         answer = &m_maintext;
         break;
     default:
-        KWTextFrameSet *newFS = new KWTextFrameSet(m_document);
-        emit newFrameSet(newFS);
-        return newFS;
+        Q_ASSERT(false); // we should never get asked for 'other'
     }
     Q_ASSERT(answer);
     if (*answer == 0) { // it wasn't created yet, lets do so now.
@@ -492,34 +533,44 @@ void KWFrameLayout::setup()
     if (m_setup)
         return;
 
+    KWTextFrameSet *oldMainText = m_maintext;
     m_maintext = 0;
+    m_backgroundFrameSet = 0;
     m_pageStyles.clear();
     foreach (KWFrameSet *fs, m_frameSets) {
-        KWTextFrameSet *tfs = dynamic_cast<KWTextFrameSet*>(fs);
-        if (tfs == 0)
-            continue;
-        FrameSets frameSets = m_pageStyles.value(tfs->pageStyle());
-        switch (tfs->textFrameSetType()) {
-        case KWord::OddPagesHeaderTextFrameSet:
-            frameSets.oddHeaders = tfs;
-            break;
-        case KWord::EvenPagesHeaderTextFrameSet:
-            frameSets.evenHeaders = tfs;
-            break;
-        case KWord::OddPagesFooterTextFrameSet:
-            frameSets.oddFooters = tfs;
-            break;
-        case KWord::EvenPagesFooterTextFrameSet:
-            frameSets.evenFooters = tfs;
-            break;
-        case KWord::MainTextFrameSet:
-            m_maintext = tfs;
-            disconnect(tfs, SIGNAL(frameRemoved(KWFrame*)), this, SLOT(mainframeRemoved(KWFrame*)));
-            connect(tfs, SIGNAL(frameRemoved(KWFrame*)), this, SLOT(mainframeRemoved(KWFrame*)));
-        default: ;// ignore
+        if (fs->type() == KWord::BackgroundFrameSet) {
+            m_backgroundFrameSet = fs;
+        } else if (fs->type() == KWord::TextFrameSet) {
+            KWTextFrameSet *tfs = static_cast<KWTextFrameSet*>(fs);
+            FrameSets frameSets = m_pageStyles.value(tfs->pageStyle());
+            switch (tfs->textFrameSetType()) {
+            case KWord::OddPagesHeaderTextFrameSet:
+                frameSets.oddHeaders = tfs;
+                break;
+            case KWord::EvenPagesHeaderTextFrameSet:
+                frameSets.evenHeaders = tfs;
+                break;
+            case KWord::OddPagesFooterTextFrameSet:
+                frameSets.oddFooters = tfs;
+                break;
+            case KWord::EvenPagesFooterTextFrameSet:
+                frameSets.evenFooters = tfs;
+                break;
+            case KWord::MainTextFrameSet:
+                Q_ASSERT(m_maintext == 0); // there can be only one!
+                if (tfs != oldMainText) {
+                    oldMainText = 0;
+                    disconnect(tfs, SIGNAL(frameRemoved(KWFrame*)),
+                            this, SLOT(mainframeRemoved(KWFrame*)));
+                    connect(tfs, SIGNAL(frameRemoved(KWFrame*)),
+                            this, SLOT(mainframeRemoved(KWFrame*)));
+                }
+                m_maintext = tfs;
+            default: ;// ignore
+            }
+            if (tfs->pageStyle().isValid())
+                m_pageStyles.insert(tfs->pageStyle(), frameSets);
         }
-        if (tfs->pageStyle().isValid())
-            m_pageStyles.insert(tfs->pageStyle(), frameSets);
     }
     m_setup = true;
 }
@@ -537,15 +588,15 @@ KoShape *KWFrameLayout::createTextShape(const KWPage &page)
     return shape;
 }
 
-bool KWFrameLayout::hasFrameOn(KWTextFrameSet *fs, int pageNumber)
+KWFrame *KWFrameLayout::frameOn(KWFrameSet *fs, int pageNumber) const
 {
     KWPage page = m_pageManager->page(pageNumber);
     Q_ASSERT(page.isValid());
     foreach (KWFrame *frame, framesInPage(page.rect())) {
         if (frame->frameSet() == fs)
-            return true;
+            return frame;
     }
-    return false;
+    return 0;
 }
 
 void KWFrameLayout::cleanupHeadersFooters()
@@ -688,6 +739,7 @@ KWFrame *KWFrameLayout::createCopyFrame(KWFrameSet *fs, const KWPage &page)
     }
 
     KoShape *orig = 0;
+    //Lets find the last non-copy frame in the frameset
     foreach (KWFrame *candidate, fs->frames()) {
         if (candidate->isCopy())
             break;
@@ -719,7 +771,7 @@ void KWFrameLayout::mainframeRemoved(KWFrame *frame)
     QList<KWFrame*> framesToDelete;
     foreach (KWFrameSet *fs, m_frameSets) {
         KWTextFrameSet *tfs = dynamic_cast<KWTextFrameSet*> (fs);
-        if (!KWord::isAutoGenerated(tfs))
+        if (!tfs || !KWord::isAutoGenerated(tfs))
             continue;
         const bool isMainFs = fs == m_maintext;
         foreach (KWFrame *f, fs->frames()) {
