@@ -22,6 +22,7 @@
 #include "KoResourceManager.h"
 #include "KoShapeController.h"
 #include "KoCanvasController.h"
+#include "KoViewConverter.h"
 #include "KoSnapGuide.h"
 #include "SnapGuideConfigWidget.h"
 
@@ -33,7 +34,13 @@
 class KoCanvasBase::Private
 {
 public:
-    Private() : shapeController(0), resourceManager(0), controller(0) {}
+    Private() : shapeController(0),
+        resourceManager(0),
+        controller(0),
+        snapGuide(0),
+        readWrite(true)
+    {
+    }
     ~Private() {
         delete shapeController;
         delete resourceManager;
@@ -43,6 +50,7 @@ public:
     KoResourceManager *resourceManager;
     KoCanvasController *controller;
     KoSnapGuide *snapGuide;
+    bool readWrite;
 };
 
 KoCanvasBase::KoCanvasBase(KoShapeControllerBase *shapeControllerBase)
@@ -71,8 +79,9 @@ KoResourceManager *KoCanvasBase::resourceManager() const
 
 void KoCanvasBase::ensureVisible(const QRectF &rect)
 {
-    if (d->controller)
-        d->controller->ensureVisible(rect);
+    if (d->controller && d->controller->canvas())
+        d->controller->ensureVisible(
+                d->controller->canvas()->viewConverter()->documentToView(rect));
 }
 
 void KoCanvasBase::setCanvasController(KoCanvasController *controller)
@@ -103,3 +112,13 @@ QWidget *KoCanvasBase::createSnapGuideConfigWidget() const
 {
     return new SnapGuideConfigWidget(d->snapGuide);
 }
+
+void KoCanvasBase::setReadWrite(bool readWrite)
+{
+    d->readWrite = readWrite;
+}
+
+bool KoCanvasBase::isReadWrite() const
+{
+    return d->readWrite;
+}
